@@ -39,7 +39,7 @@ panel.parallel <-
              lwd = superpose.line$lwd,
              lty = superpose.line$lty,
              alpha = superpose.line$alpha,
-             common.scale = TRUE,
+             common.scale = FALSE,
              lower = sapply(z, function(x) min(as.numeric(x), na.rm = TRUE)),
              upper = sapply(z, function(x) max(as.numeric(x), na.rm = TRUE)),
              ...)
@@ -66,7 +66,9 @@ panel.parallel <-
         alpha <- rep(alpha, length = n.g)
     }
 
-    if (!common.scale)
+    if (is.function(lower)) lower <- sapply(z, lower)
+    if (is.function(upper)) upper <- sapply(z, upper)
+    if (common.scale)
     {
         lower <- min(lower)
         upper <- max(upper)
@@ -179,13 +181,13 @@ parallel <- function(x, data, ...) UseMethod("parallel")
 ##     else UseMethod("parallel")
 ## }
 
-
+parallel.matrix <-
 parallel.data.frame <-
     function(x, data = NULL, ...)
 {
     ocall <- ccall <- match.call()
     if (!is.null(ccall$data)) 
-        warning("explicit data specification ignored")
+        warning("explicit 'data' specification ignored")
     ccall$data <- list(x = x)
     ccall$x <- ~x
     ccall[[1]] <- as.name("parallel")
@@ -200,7 +202,7 @@ parallel.formula <-
              data = NULL,
              aspect = "fill",
              between = list(x = 0.5, y = 0.5),
-             panel = "panel.parallel",
+             panel = lattice.getOption("panel.parallel"),
              prepanel = NULL,
              scales = list(),
              strip = TRUE,
