@@ -43,7 +43,9 @@ assign("last.object",     NULL,   env = .LatticeEnv)
 
 ## .First.lib will be used if the NAMESPACE file is missing.  This is
 ## useful during development, thanks to C-c C-l in Emacs/ESS. It won't
-## be used if a NAMESPACE file is present.
+## be used if a NAMESPACE file is present.  Note: Due to registration
+## of C functions done in the NAMESPACE file, wireframe (and possibly
+## cloud) won't work in this scenario.
 
 
 .First.lib <- function(lib, pkg) 
@@ -51,7 +53,7 @@ assign("last.object",     NULL,   env = .LatticeEnv)
     cat(gettext("Note: you shouldn't be seeing this message unless\nyou are using a non-standard version of lattice"),
         fill = TRUE)
     library.dynam(pkg, pkg, lib )
-    if (!require(grid)) stop("The grid package couldn't be loaded.\nPlease check your installation of R")
+    if (!require("grid")) stop("The grid package couldn't be loaded.\nPlease check your installation of R")
     lattice.options(.defaultLatticeOptions())
     lattice.setStatus(.defaultLatticeStatus())
 }
